searchData={"items":[{"type":"module","doc":"Bindings for Arrow Database Connectivity (ADBC).\n\nAdbc provides a standard database interface using the\nApache Arrow format.","title":"Adbc","ref":"Adbc.html"},{"type":"module","doc":"First, add `:adbc` as a dependency in your `mix.exs`:\n\n    {:adbc, \"~> 0.1\"}\n\nNow, in your config/config.exs, configure the drivers you\nare going to use:\n\n    config :adbc, :drivers, [:sqlite]\n\nIf you are using a notebook or scripting, you can also use\n`Adbc.download_driver!/1` to dynamically download one.\n\nThen start the database and the relevant connection processes\nin your supervision tree:\n\n    children = [\n      {Adbc.Database,\n       driver: :sqlite,\n       process_options: [name: MyApp.DB]},\n      {Adbc.Connection,\n       database: MyApp.DB,\n       process_options: [name: MyApp.Conn]}\n    ]\n\n    Supervisor.start_link(children, strategy: :one_for_one)\n\nIn a notebook, the above would look like this:\n\n    db = Kino.start_child!({Adbc.Database, driver: :sqlite})\n    conn = Kino.start_child!({Adbc.Connection, database: db})\n\nAnd now you can make queries with:\n\n    # For named connections\n    {:ok, _} = Adbc.Connection.query(MyApp.Conn, \"SELECT 123\")\n\n    # When using the conn PID directly\n    {:ok, _} = Adbc.Connection.query(conn, \"SELECT 123\")","title":"Installation - Adbc","ref":"Adbc.html#module-installation"},{"type":"module","doc":"Below we list all drivers supported out of the box. You may also\ngive the full path to a driver in the `:driver` option to load other\nexisting drivers.\n\n#","title":"Supported drivers - Adbc","ref":"Adbc.html#module-supported-drivers"},{"type":"module","doc":"The DuckDB driver provides access to in-memory DuckDB databases.\n\n##","title":"DuckDB - Adbc","ref":"Adbc.html#module-duckdb"},{"type":"module","doc":"{Adbc.Database, driver: :duckdb}\n\n#","title":"Examples - Adbc","ref":"Adbc.html#module-examples"},{"type":"module","doc":"The PostgreSQL driver provides access to any database that supports\nthe PostgreSQL wire format. It is implemented as a wrapper around\n`libpq`.\n\n##","title":"PostgreSQL - Adbc","ref":"Adbc.html#module-postgresql"},{"type":"module","doc":"{Adbc.Database, driver: :postgresql, uri: \"postgresql://postgres@localhost\"}\n\nYou must pass the `:uri` option using Postgres'\n[connection URI](https://www.postgresql.org/docs/current/libpq-connect.html#LIBPQ-CONNSTRING):\n\n#","title":"Examples - Adbc","ref":"Adbc.html#module-examples"},{"type":"module","doc":"The SQLite driver provides access to SQLite databases.\n\n##","title":"Sqlite - Adbc","ref":"Adbc.html#module-sqlite"},{"type":"module","doc":"{Adbc.Database, driver: :sqlite, uri: \":memory:\"}\n    {Adbc.Database, driver: :sqlite, uri: \"./db/my.db\"}\n    {Adbc.Database, driver: :sqlite, uri: \"file:/path/to/file/in/disk.db\"}\n\nThe `:uri` option should be, \":memory:\", a filename or\n[URI filename](https://www.sqlite.org/c3ref/open.html#urifilenamesinsqlite3open).\nIf omitted, it will default to an in-memory database, but\none that is shared across all connections.\n\n#","title":"Examples - Adbc","ref":"Adbc.html#module-examples"},{"type":"module","doc":"The Snowflake driver provides access to Snowflake Database Warehouses.\n\n##","title":"Snowflake - Adbc","ref":"Adbc.html#module-snowflake"},{"type":"module","doc":"{Adbc.Database, driver: :snowflake, uri: \"...\"}\n\nThe Snowflake URI should be of one of the following formats:\n\n    user[:password]@account/database/schema[?param1=value1&paramN=valueN]\n    user[:password]@account/database[?param1=value1&paramN=valueN]\n    user[:password]@host:port/database/schema?account=user_account[&param1=value1&paramN=valueN]\n    host:port/database/schema?account=user_account[&param1=value1&paramN=valueN]\n\nThe first two are the most recommended formats. The schema, database and parameters are optional.\nSee [Account identifiers](https://docs.snowflake.com/en/user-guide/admin-account-identifier) for more information.","title":"Examples - Adbc","ref":"Adbc.html#module-examples"},{"type":"function","doc":"Downloads a driver.\n\nSee `Adbc` module doc for all supports drivers.\nIt returns `:ok` or `{:error, binary}`.","title":"Adbc.download_driver/2","ref":"Adbc.html#download_driver/2"},{"type":"function","doc":"Downloads a driver and raises in case of errors.\n\nSee `Adbc` module doc for all supports drivers.\nIt returns `:ok`.","title":"Adbc.download_driver!/2","ref":"Adbc.html#download_driver!/2"},{"type":"module","doc":"Documentation for `Adbc.Column`.\n\n`Adbc.Column` corresponds to a column in the table. It contains the column's name, type, and\ndata. The data is a list of values of the column's data type.","title":"Adbc.Column","ref":"Adbc.Column.html"},{"type":"function","doc":"A column that contains binary values.","title":"Adbc.Column.binary/2","ref":"Adbc.Column.html#binary/2"},{"type":"function","doc":"* `data`: A list of binary values\n* `opts`: A keyword list of options","title":"Arguments - Adbc.Column.binary/2","ref":"Adbc.Column.html#binary/2-arguments"},{"type":"function","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","title":"Options - Adbc.Column.binary/2","ref":"Adbc.Column.html#binary/2-options"},{"type":"function","doc":"iex> Adbc.Column.binary([<<0>>, <<1>>, <<2>>])\n    %Adbc.Column{\n      name: nil,\n      type: :binary,\n      nullable: false,\n      metadata: %{},\n      data: [<<0>>, <<1>>, <<2>>]\n    }","title":"Examples - Adbc.Column.binary/2","ref":"Adbc.Column.html#binary/2-examples"},{"type":"function","doc":"A column that contains booleans.","title":"Adbc.Column.boolean/2","ref":"Adbc.Column.html#boolean/2"},{"type":"function","doc":"* `data`: A list of booleans\n* `opts`: A keyword list of options","title":"Arguments - Adbc.Column.boolean/2","ref":"Adbc.Column.html#boolean/2-arguments"},{"type":"function","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","title":"Options - Adbc.Column.boolean/2","ref":"Adbc.Column.html#boolean/2-options"},{"type":"function","doc":"iex> Adbc.Column.boolean([true, false, true])\n    %Adbc.Column{\n      name: nil,\n      type: :boolean,\n      nullable: false,\n      metadata: %{},\n      data: [true, false, true]\n    }","title":"Examples - Adbc.Column.boolean/2","ref":"Adbc.Column.html#boolean/2-examples"},{"type":"function","doc":"","title":"Adbc.Column.column/3","ref":"Adbc.Column.html#column/3"},{"type":"function","doc":"A column that contains date represented as 32-bit signed integers in UTC.","title":"Adbc.Column.date32/2","ref":"Adbc.Column.html#date32/2"},{"type":"function","doc":"* `data`: a list, each element of which can be one of the following:\n  * a `Date.t()`\n  * a 32-bit signed integer representing the number of days since the Unix epoch.\n* `opts`: A keyword list of options","title":"Arguments - Adbc.Column.date32/2","ref":"Adbc.Column.html#date32/2-arguments"},{"type":"function","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","title":"Options - Adbc.Column.date32/2","ref":"Adbc.Column.html#date32/2-options"},{"type":"function","doc":"A column that contains date represented as 64-bit signed integers in UTC.","title":"Adbc.Column.date64/2","ref":"Adbc.Column.html#date64/2"},{"type":"function","doc":"* `data`: a list, each element of which can be one of the following:\n  * a `Date.t()`\n  * a 64-bit signed integer representing the number of milliseconds since the Unix epoch.\n* `opts`: A keyword list of options","title":"Arguments - Adbc.Column.date64/2","ref":"Adbc.Column.html#date64/2-arguments"},{"type":"function","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","title":"Options - Adbc.Column.date64/2","ref":"Adbc.Column.html#date64/2-options"},{"type":"function","doc":"A column that contains 128-bit decimals.","title":"Adbc.Column.decimal128/4","ref":"Adbc.Column.html#decimal128/4"},{"type":"function","doc":"* `data`: a list, each element can be either\n  * a `Decimal.t()`\n  * an `integer()`\n* `precision`: The precision of the decimal values; precision should be between 1 and 38\n* `scale`: The scale of the decimal values\n* `opts`: A keyword list of options","title":"Arguments - Adbc.Column.decimal128/4","ref":"Adbc.Column.html#decimal128/4-arguments"},{"type":"function","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","title":"Options - Adbc.Column.decimal128/4","ref":"Adbc.Column.html#decimal128/4-options"},{"type":"function","doc":"A column that contains 256-bit decimals.","title":"Adbc.Column.decimal256/4","ref":"Adbc.Column.html#decimal256/4"},{"type":"function","doc":"* `data`: a list, each element can be either\n  * a `Decimal.t()`\n  * an `integer()`\n* `precision`: The precision of the decimal values; precision should be between 1 and 76\n* `scale`: The scale of the decimal values\n* `opts`: A keyword list of options","title":"Arguments - Adbc.Column.decimal256/4","ref":"Adbc.Column.html#decimal256/4-arguments"},{"type":"function","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","title":"Options - Adbc.Column.decimal256/4","ref":"Adbc.Column.html#decimal256/4-options"},{"type":"function","doc":"","title":"Adbc.Column.delete_all_metadata/1","ref":"Adbc.Column.html#delete_all_metadata/1"},{"type":"function","doc":"","title":"Adbc.Column.delete_metadata/2","ref":"Adbc.Column.html#delete_metadata/2"},{"type":"function","doc":"A column that contains durations represented as 64-bit signed integers.","title":"Adbc.Column.duration/3","ref":"Adbc.Column.html#duration/3"},{"type":"function","doc":"* `data`: a list of integer values representing the time in the specified unit\n\n* `unit`: specify the unit of the time value, one of the following:\n  * `:seconds`\n  * `:milliseconds`\n  * `:microseconds`\n  * `:nanoseconds`\n\n* `opts`: A keyword list of options","title":"Arguments - Adbc.Column.duration/3","ref":"Adbc.Column.html#duration/3-arguments"},{"type":"function","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","title":"Options - Adbc.Column.duration/3","ref":"Adbc.Column.html#duration/3-options"},{"type":"function","doc":"A column that contains 16-bit half-precision floats.","title":"Adbc.Column.f16/2","ref":"Adbc.Column.html#f16/2"},{"type":"function","doc":"* `data`: A list of 32-bit single-precision float values (will be converted to 16-bit floats in C)\n* `opts`: A keyword list of options","title":"Arguments - Adbc.Column.f16/2","ref":"Adbc.Column.html#f16/2-arguments"},{"type":"function","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","title":"Options - Adbc.Column.f16/2","ref":"Adbc.Column.html#f16/2-options"},{"type":"function","doc":"iex> Adbc.Column.f16([1.0, 2.0, 3.0])\n    %Adbc.Column{\n      name: nil,\n      type: :f16,\n      nullable: false,\n      metadata: %{},\n      data: [1.0, 2.0, 3.0]\n    }","title":"Examples - Adbc.Column.f16/2","ref":"Adbc.Column.html#f16/2-examples"},{"type":"function","doc":"A column that contains 32-bit single-precision floats.","title":"Adbc.Column.f32/2","ref":"Adbc.Column.html#f32/2"},{"type":"function","doc":"* `data`: A list of 32-bit single-precision float values\n* `opts`: A keyword list of options","title":"Arguments - Adbc.Column.f32/2","ref":"Adbc.Column.html#f32/2-arguments"},{"type":"function","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","title":"Options - Adbc.Column.f32/2","ref":"Adbc.Column.html#f32/2-options"},{"type":"function","doc":"iex> Adbc.Column.f32([1.0, 2.0, 3.0])\n    %Adbc.Column{\n      name: nil,\n      type: :f32,\n      nullable: false,\n      metadata: %{},\n      data: [1.0, 2.0, 3.0]\n    }","title":"Examples - Adbc.Column.f32/2","ref":"Adbc.Column.html#f32/2-examples"},{"type":"function","doc":"A column that contains 64-bit double-precision floats.","title":"Adbc.Column.f64/2","ref":"Adbc.Column.html#f64/2"},{"type":"function","doc":"* `data`: A list of 64-bit double-precision float values\n* `opts`: A keyword list of options","title":"Arguments - Adbc.Column.f64/2","ref":"Adbc.Column.html#f64/2-arguments"},{"type":"function","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","title":"Options - Adbc.Column.f64/2","ref":"Adbc.Column.html#f64/2-options"},{"type":"function","doc":"iex> Adbc.Column.f64([1.0, 2.0, 3.0])\n    %Adbc.Column{\n      name: nil,\n      type: :f64,\n      nullable: false,\n      metadata: %{},\n      data: [1.0, 2.0, 3.0]\n    }","title":"Examples - Adbc.Column.f64/2","ref":"Adbc.Column.html#f64/2-examples"},{"type":"function","doc":"A column that contains fixed size binaries.\n\nSimilar to `binary/2`, but each binary value has the same fixed size in bytes.","title":"Adbc.Column.fixed_size_binary/3","ref":"Adbc.Column.html#fixed_size_binary/3"},{"type":"function","doc":"* `data`: A list of binary values\n* `nbytes`: The fixed size of the binary values in bytes\n* `opts`: A keyword list of options","title":"Arguments - Adbc.Column.fixed_size_binary/3","ref":"Adbc.Column.html#fixed_size_binary/3-arguments"},{"type":"function","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","title":"Options - Adbc.Column.fixed_size_binary/3","ref":"Adbc.Column.html#fixed_size_binary/3-options"},{"type":"function","doc":"iex> Adbc.Column.fixed_size_binary([<<0>>, <<1>>, <<2>>], 1)\n    %Adbc.Column{\n      name: nil,\n      type: {:fixed_size_binary, 1},\n      nullable: false,\n      metadata: %{},\n      data: [<<0>>, <<1>>, <<2>>]\n    }","title":"Examples - Adbc.Column.fixed_size_binary/3","ref":"Adbc.Column.html#fixed_size_binary/3-examples"},{"type":"function","doc":"Similar to `list/2`, but the length of the list is the same.","title":"Adbc.Column.fixed_size_list/3","ref":"Adbc.Column.html#fixed_size_list/3"},{"type":"function","doc":"* `data`: a list, each element of which can be one of the following:\n  - `nil`\n  - `Adbc.Column`\n\n  Note that each `Adbc.Column` in the list should have the same type and length.\n\n* `fixed_size`: The fixed size of the list.\n\n* `opts`: A keyword list of options","title":"Arguments - Adbc.Column.fixed_size_list/3","ref":"Adbc.Column.html#fixed_size_list/3-arguments"},{"type":"function","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","title":"Options - Adbc.Column.fixed_size_list/3","ref":"Adbc.Column.html#fixed_size_list/3-options"},{"type":"function","doc":"","title":"Adbc.Column.get_metadata/3","ref":"Adbc.Column.html#get_metadata/3"},{"type":"function","doc":"A column that contains signed 8-bit integers.","title":"Adbc.Column.i8/2","ref":"Adbc.Column.html#i8/2"},{"type":"function","doc":"* `data`: A list of signed 8-bit integer values\n* `opts`: A keyword list of options","title":"Arguments - Adbc.Column.i8/2","ref":"Adbc.Column.html#i8/2-arguments"},{"type":"function","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","title":"Options - Adbc.Column.i8/2","ref":"Adbc.Column.html#i8/2-options"},{"type":"function","doc":"iex> Adbc.Column.i8([1, 2, 3])\n    %Adbc.Column{\n      name: nil,\n      type: :i8,\n      nullable: false,\n      metadata: %{},\n      data: [1, 2, 3]\n    }","title":"Examples - Adbc.Column.i8/2","ref":"Adbc.Column.html#i8/2-examples"},{"type":"function","doc":"A column that contains signed 16-bit integers.","title":"Adbc.Column.i16/2","ref":"Adbc.Column.html#i16/2"},{"type":"function","doc":"* `data`: A list of signed 16-bit integer values\n* `opts`: A keyword list of options","title":"Arguments - Adbc.Column.i16/2","ref":"Adbc.Column.html#i16/2-arguments"},{"type":"function","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","title":"Options - Adbc.Column.i16/2","ref":"Adbc.Column.html#i16/2-options"},{"type":"function","doc":"iex> Adbc.Column.i16([1, 2, 3])\n    %Adbc.Column{\n      name: nil,\n      type: :i16,\n      nullable: false,\n      metadata: %{},\n      data: [1, 2, 3]\n    }","title":"Examples - Adbc.Column.i16/2","ref":"Adbc.Column.html#i16/2-examples"},{"type":"function","doc":"A column that contains 32-bit signed integers.","title":"Adbc.Column.i32/2","ref":"Adbc.Column.html#i32/2"},{"type":"function","doc":"* `data`: A list of 32-bit signed integer values\n* `opts`: A keyword list of options","title":"Arguments - Adbc.Column.i32/2","ref":"Adbc.Column.html#i32/2-arguments"},{"type":"function","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","title":"Options - Adbc.Column.i32/2","ref":"Adbc.Column.html#i32/2-options"},{"type":"function","doc":"iex> Adbc.Column.i32([1, 2, 3])\n    %Adbc.Column{\n      name: nil,\n      type: :i32,\n      nullable: false,\n      metadata: %{},\n      data: [1, 2, 3]\n    }","title":"Examples - Adbc.Column.i32/2","ref":"Adbc.Column.html#i32/2-examples"},{"type":"function","doc":"A column that contains 64-bit signed integers.","title":"Adbc.Column.i64/2","ref":"Adbc.Column.html#i64/2"},{"type":"function","doc":"* `data`: A list of 64-bit signed integer values\n* `opts`: A keyword list of options","title":"Arguments - Adbc.Column.i64/2","ref":"Adbc.Column.html#i64/2-arguments"},{"type":"function","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","title":"Options - Adbc.Column.i64/2","ref":"Adbc.Column.html#i64/2-options"},{"type":"function","doc":"iex> Adbc.Column.i64([1, 2, 3])\n    %Adbc.Column{\n      name: nil,\n      type: :i64,\n      nullable: false,\n      metadata: %{},\n      data: [1, 2, 3]\n    }","title":"Examples - Adbc.Column.i64/2","ref":"Adbc.Column.html#i64/2-examples"},{"type":"function","doc":"A column that contains durations represented as signed integers.","title":"Adbc.Column.interval/3","ref":"Adbc.Column.html#interval/3"},{"type":"function","doc":"* `data`: a list, each element of which can be one of the following:\n  - if `unit` is `:month`:\n    * a 32-bit signed integer representing the number of months.\n\n  - if `unit` is `:day_time`:\n    * a 2-tuple, both the number of days and the number of milliseconds are in 32-bit signed integers.\n\n  - if `unit` is `:month_day_nano`:\n    * a 3-tuple, the number of months, days, and nanoseconds;\n      the number of months and days are in 32-bit signed integers,\n      and the number of nanoseconds is in 64-bit signed integers\n\n* `unit`: specify the unit of the time value, one of the following:\n  * `:month`\n  * `:day_time`\n  * `:month_day_nano`\n\n* `opts`: A keyword list of options","title":"Arguments - Adbc.Column.interval/3","ref":"Adbc.Column.html#interval/3-arguments"},{"type":"function","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","title":"Options - Adbc.Column.interval/3","ref":"Adbc.Column.html#interval/3-options"},{"type":"function","doc":"A column that contains large binary values.\n\nSimilar to `binary/2`, but for binary values larger than 2GB.","title":"Adbc.Column.large_binary/2","ref":"Adbc.Column.html#large_binary/2"},{"type":"function","doc":"* `data`: A list of binary values\n* `opts`: A keyword list of options","title":"Arguments - Adbc.Column.large_binary/2","ref":"Adbc.Column.html#large_binary/2-arguments"},{"type":"function","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","title":"Options - Adbc.Column.large_binary/2","ref":"Adbc.Column.html#large_binary/2-options"},{"type":"function","doc":"iex> Adbc.Column.large_binary([<<0>>, <<1>>, <<2>>])\n    %Adbc.Column{\n      name: nil,\n      type: :large_binary,\n      nullable: false,\n      metadata: %{},\n      data: [<<0>>, <<1>>, <<2>>]\n    }","title":"Examples - Adbc.Column.large_binary/2","ref":"Adbc.Column.html#large_binary/2-examples"},{"type":"function","doc":"Similar to `list/2`, but for large lists.","title":"Adbc.Column.large_list/2","ref":"Adbc.Column.html#large_list/2"},{"type":"function","doc":"* `data`: a list, each element of which can be one of the following:\n  - `nil`\n  - `Adbc.Column`\n\n  Note that each `Adbc.Column` in the list should have the same type.\n\n* `opts`: A keyword list of options","title":"Arguments - Adbc.Column.large_list/2","ref":"Adbc.Column.html#large_list/2-arguments"},{"type":"function","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","title":"Options - Adbc.Column.large_list/2","ref":"Adbc.Column.html#large_list/2-options"},{"type":"function","doc":"A column that contains UTF-8 encoded large strings.\n\nSimilar to `string/2`, but for strings larger than 2GB.","title":"Adbc.Column.large_string/2","ref":"Adbc.Column.html#large_string/2"},{"type":"function","doc":"* `data`: A list of UTF-8 encoded string values\n* `opts`: A keyword list of options","title":"Arguments - Adbc.Column.large_string/2","ref":"Adbc.Column.html#large_string/2-arguments"},{"type":"function","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","title":"Options - Adbc.Column.large_string/2","ref":"Adbc.Column.html#large_string/2-options"},{"type":"function","doc":"iex> Adbc.Column.large_string([\"a\", \"ab\", \"abc\"])\n    %Adbc.Column{\n      name: nil,\n      type: :large_string,\n      nullable: false,\n      metadata: %{},\n      data: [\"a\", \"ab\", \"abc\"]\n    }","title":"Examples - Adbc.Column.large_string/2","ref":"Adbc.Column.html#large_string/2-examples"},{"type":"function","doc":"A column that each row is a list of some type or nil.","title":"Adbc.Column.list/2","ref":"Adbc.Column.html#list/2"},{"type":"function","doc":"* `data`: a list, each element of which can be one of the following:\n  - `nil`\n  - `Adbc.Column`\n\n  Note that each `Adbc.Column` in the list should have the same type.\n\n* `opts`: A keyword list of options","title":"Arguments - Adbc.Column.list/2","ref":"Adbc.Column.html#list/2-arguments"},{"type":"function","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","title":"Options - Adbc.Column.list/2","ref":"Adbc.Column.html#list/2-options"},{"type":"function","doc":"","title":"Adbc.Column.set_metadata/3","ref":"Adbc.Column.html#set_metadata/3"},{"type":"function","doc":"A column that contains UTF-8 encoded strings.","title":"Adbc.Column.string/2","ref":"Adbc.Column.html#string/2"},{"type":"function","doc":"* `data`: A list of UTF-8 encoded string values\n* `opts`: A keyword list of options","title":"Arguments - Adbc.Column.string/2","ref":"Adbc.Column.html#string/2-arguments"},{"type":"function","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","title":"Options - Adbc.Column.string/2","ref":"Adbc.Column.html#string/2-options"},{"type":"function","doc":"iex> Adbc.Column.string([\"a\", \"ab\", \"abc\"])\n    %Adbc.Column{\n      name: nil,\n      type: :string,\n      nullable: false,\n      metadata: %{},\n      data: [\"a\", \"ab\", \"abc\"]\n    }","title":"Examples - Adbc.Column.string/2","ref":"Adbc.Column.html#string/2-examples"},{"type":"function","doc":"A column that contains time represented as signed integers in UTC.","title":"Adbc.Column.time/3","ref":"Adbc.Column.html#time/3"},{"type":"function","doc":"* `data`:\n  * a list of `Time.t()` value\n  * a list of integer values representing the time in the specified unit\n\n    Note that when using `:seconds` or `:milliseconds` as the unit,\n    the time value is limited to the range of 32-bit signed integers.\n\n    For `:microseconds` and `:nanoseconds`, the time value is limited to the range of 64-bit signed integers.\n\n* `unit`: specify the unit of the time value, one of the following:\n  * `:seconds`\n  * `:milliseconds`\n  * `:microseconds`\n  * `:nanoseconds`\n\n* `opts`: A keyword list of options","title":"Arguments - Adbc.Column.time/3","ref":"Adbc.Column.html#time/3-arguments"},{"type":"function","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","title":"Options - Adbc.Column.time/3","ref":"Adbc.Column.html#time/3-options"},{"type":"function","doc":"A column that contains timestamps represented as signed integers in the given timezone.","title":"Adbc.Column.timestamp/4","ref":"Adbc.Column.html#timestamp/4"},{"type":"function","doc":"* `data`:\n  * a list of `NaiveDateTime.t()` value\n  * a list of 64-bit signed integer values representing the time in the specified unit\n\n* `unit`: specify the unit of the time value, one of the following:\n  * `:seconds`\n  * `:milliseconds`\n  * `:microseconds`\n  * `:nanoseconds`\n\n* `timezone`: the timezone of the timestamp\n\n* `opts`: A keyword list of options","title":"Arguments - Adbc.Column.timestamp/4","ref":"Adbc.Column.html#timestamp/4-arguments"},{"type":"function","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","title":"Options - Adbc.Column.timestamp/4","ref":"Adbc.Column.html#timestamp/4-options"},{"type":"function","doc":"A column that contains unsigned 8-bit integers.","title":"Adbc.Column.u8/2","ref":"Adbc.Column.html#u8/2"},{"type":"function","doc":"* `data`: A list of unsigned 8-bit integer values\n* `opts`: A keyword list of options","title":"Arguments - Adbc.Column.u8/2","ref":"Adbc.Column.html#u8/2-arguments"},{"type":"function","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","title":"Options - Adbc.Column.u8/2","ref":"Adbc.Column.html#u8/2-options"},{"type":"function","doc":"iex> Adbc.Column.u8([1, 2, 3])\n    %Adbc.Column{\n      name: nil,\n      type: :u8,\n      nullable: false,\n      metadata: %{},\n      data: [1, 2, 3]\n    }","title":"Examples - Adbc.Column.u8/2","ref":"Adbc.Column.html#u8/2-examples"},{"type":"function","doc":"A column that contains unsigned 16-bit integers.","title":"Adbc.Column.u16/2","ref":"Adbc.Column.html#u16/2"},{"type":"function","doc":"* `data`: A list of unsigned 16-bit integer values\n* `opts`: A keyword list of options","title":"Arguments - Adbc.Column.u16/2","ref":"Adbc.Column.html#u16/2-arguments"},{"type":"function","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","title":"Options - Adbc.Column.u16/2","ref":"Adbc.Column.html#u16/2-options"},{"type":"function","doc":"iex> Adbc.Column.u16([1, 2, 3])\n    %Adbc.Column{\n      name: nil,\n      type: :u16,\n      nullable: false,\n      metadata: %{},\n      data: [1, 2, 3]\n    }","title":"Examples - Adbc.Column.u16/2","ref":"Adbc.Column.html#u16/2-examples"},{"type":"function","doc":"A column that contains un32-bit signed integers.","title":"Adbc.Column.u32/2","ref":"Adbc.Column.html#u32/2"},{"type":"function","doc":"* `data`: A list of un32-bit signed integer values\n* `opts`: A keyword list of options","title":"Arguments - Adbc.Column.u32/2","ref":"Adbc.Column.html#u32/2-arguments"},{"type":"function","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","title":"Options - Adbc.Column.u32/2","ref":"Adbc.Column.html#u32/2-options"},{"type":"function","doc":"iex> Adbc.Column.u32([1, 2, 3])\n    %Adbc.Column{\n      name: nil,\n      type: :u32,\n      nullable: false,\n      metadata: %{},\n      data: [1, 2, 3]\n    }","title":"Examples - Adbc.Column.u32/2","ref":"Adbc.Column.html#u32/2-examples"},{"type":"function","doc":"A column that contains un64-bit signed integers.","title":"Adbc.Column.u64/2","ref":"Adbc.Column.html#u64/2"},{"type":"function","doc":"* `data`: A list of un64-bit signed integer values\n* `opts`: A keyword list of options","title":"Arguments - Adbc.Column.u64/2","ref":"Adbc.Column.html#u64/2-arguments"},{"type":"function","doc":"* `:name` - The name of the column\n* `:nullable` - A boolean value indicating whether the column is nullable\n* `:metadata` - A map of metadata","title":"Options - Adbc.Column.u64/2","ref":"Adbc.Column.html#u64/2-options"},{"type":"function","doc":"iex> Adbc.Column.u32([1, 2, 3])\n    %Adbc.Column{\n      name: nil,\n      type: :u32,\n      nullable: false,\n      metadata: %{},\n      data: [1, 2, 3]\n    }","title":"Examples - Adbc.Column.u64/2","ref":"Adbc.Column.html#u64/2-examples"},{"type":"type","doc":"","title":"Adbc.Column.data_type/0","ref":"Adbc.Column.html#t:data_type/0"},{"type":"type","doc":"","title":"Adbc.Column.decimal128/0","ref":"Adbc.Column.html#t:decimal128/0"},{"type":"type","doc":"","title":"Adbc.Column.decimal256/0","ref":"Adbc.Column.html#t:decimal256/0"},{"type":"type","doc":"","title":"Adbc.Column.decimal_t/0","ref":"Adbc.Column.html#t:decimal_t/0"},{"type":"type","doc":"","title":"Adbc.Column.duration_t/0","ref":"Adbc.Column.html#t:duration_t/0"},{"type":"type","doc":"","title":"Adbc.Column.floating/0","ref":"Adbc.Column.html#t:floating/0"},{"type":"type","doc":"","title":"Adbc.Column.i8/0","ref":"Adbc.Column.html#t:i8/0"},{"type":"type","doc":"","title":"Adbc.Column.i16/0","ref":"Adbc.Column.html#t:i16/0"},{"type":"type","doc":"","title":"Adbc.Column.i32/0","ref":"Adbc.Column.html#t:i32/0"},{"type":"type","doc":"","title":"Adbc.Column.i64/0","ref":"Adbc.Column.html#t:i64/0"},{"type":"type","doc":"","title":"Adbc.Column.interval_day_time/0","ref":"Adbc.Column.html#t:interval_day_time/0"},{"type":"type","doc":"","title":"Adbc.Column.interval_month/0","ref":"Adbc.Column.html#t:interval_month/0"},{"type":"type","doc":"","title":"Adbc.Column.interval_month_day_nano/0","ref":"Adbc.Column.html#t:interval_month_day_nano/0"},{"type":"type","doc":"","title":"Adbc.Column.interval_t/0","ref":"Adbc.Column.html#t:interval_t/0"},{"type":"type","doc":"","title":"Adbc.Column.interval_unit/0","ref":"Adbc.Column.html#t:interval_unit/0"},{"type":"type","doc":"","title":"Adbc.Column.precision128/0","ref":"Adbc.Column.html#t:precision128/0"},{"type":"type","doc":"","title":"Adbc.Column.precision256/0","ref":"Adbc.Column.html#t:precision256/0"},{"type":"type","doc":"","title":"Adbc.Column.signed_integer/0","ref":"Adbc.Column.html#t:signed_integer/0"},{"type":"type","doc":"","title":"Adbc.Column.time32_t/0","ref":"Adbc.Column.html#t:time32_t/0"},{"type":"type","doc":"","title":"Adbc.Column.time64_t/0","ref":"Adbc.Column.html#t:time64_t/0"},{"type":"type","doc":"","title":"Adbc.Column.time_t/0","ref":"Adbc.Column.html#t:time_t/0"},{"type":"type","doc":"","title":"Adbc.Column.time_unit/0","ref":"Adbc.Column.html#t:time_unit/0"},{"type":"type","doc":"","title":"Adbc.Column.timestamp_t/0","ref":"Adbc.Column.html#t:timestamp_t/0"},{"type":"type","doc":"","title":"Adbc.Column.u8/0","ref":"Adbc.Column.html#t:u8/0"},{"type":"type","doc":"","title":"Adbc.Column.u16/0","ref":"Adbc.Column.html#t:u16/0"},{"type":"type","doc":"","title":"Adbc.Column.u32/0","ref":"Adbc.Column.html#t:u32/0"},{"type":"type","doc":"","title":"Adbc.Column.u64/0","ref":"Adbc.Column.html#t:u64/0"},{"type":"type","doc":"","title":"Adbc.Column.unsigned_integer/0","ref":"Adbc.Column.html#t:unsigned_integer/0"},{"type":"module","doc":"Documentation for `Adbc.Connection`.\n\nConnection are modelled as processes. They require\nan `Adbc.Database` to be started.","title":"Adbc.Connection","ref":"Adbc.Connection.html"},{"type":"function","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","title":"Adbc.Connection.child_spec/1","ref":"Adbc.Connection.html#child_spec/1"},{"type":"function","doc":"Get a binary (bytes) type option of the connection.","title":"Adbc.Connection.get_binary_option/2","ref":"Adbc.Connection.html#get_binary_option/2"},{"type":"function","doc":"Gets the underlying driver of a connection process.","title":"Adbc.Connection.get_driver/1","ref":"Adbc.Connection.html#get_driver/1"},{"type":"function","doc":"ADBC.Connection.get_driver(conn)\n    #=> {:ok, :sqlite}","title":"Examples - Adbc.Connection.get_driver/1","ref":"Adbc.Connection.html#get_driver/1-examples"},{"type":"function","doc":"Get a float type option of the connection.","title":"Adbc.Connection.get_float_option/2","ref":"Adbc.Connection.html#get_float_option/2"},{"type":"function","doc":"Get metadata about the database/driver.\n\nThe result is an Arrow dataset with the following schema:\n\n\n| Field Name                 |  Field Type    | Null Contstraint  |\n| -------------------------- | ---------------|------------------ |\n| `info_name`                |  `uint32`      | not null          |\n| `info_value`               |  `INFO_SCHEMA` |                   |\n\n`INFO_SCHEMA` is a dense union with members:\n\n| Field Name       | Type Code |  Field Type                   |\n| -----------------| --------- | ----------------------------- |\n| `string_value`              | 0 |  `utf8`                    |\n| `bool_value`                | 1 |  `bool`                    |\n| `int64_value`               | 2 |  `int64`                   |\n| `int32_bitmask`             | 3 |  `int32`                   |\n| `string_list`               | 4 |  `list `              |\n| `int32_to_int32_list_map`   | 5 |  `map >` |\n\nEach metadatum is identified by an integer code. The recognized\ncodes are defined as constants. Codes [0, 10_000) are reserved\nfor ADBC usage. Drivers/vendors will ignore requests for\nunrecognized codes (the row will be omitted from the result).","title":"Adbc.Connection.get_info/2","ref":"Adbc.Connection.html#get_info/2"},{"type":"function","doc":"Get an integer type option of the connection.","title":"Adbc.Connection.get_integer_option/2","ref":"Adbc.Connection.html#get_integer_option/2"},{"type":"function","doc":"Get a hierarchical view of all catalogs, database schemas, tables, and columns.\n\nThe result is an Arrow dataset with the following schema:\n\n| Field Name               | Field Type                |\n|--------------------------|---------------------------|\n| `catalog_name`           | `utf8`                    |\n| `catalog_db_schemas`     | `list `  |\n\n`DB_SCHEMA_SCHEMA` is a Struct with fields:\n\n| Field Name             | Field Type              |\n|------------------------|-------------------------|\n| `db_schema_name`       | `utf8`                  |\n| `db_schema_tables`     | `list `    |\n\n`TABLE_SCHEMA` is a Struct with fields:\n\n| Field Name           | Field Type                | Null Contstraint   |\n|----------------------|---------------------------|--------------------|\n| `table_name`         | `utf8`                    | not null           |\n| `table_type`         | `utf8`                    | not null           |\n| `table_columns`      | `list `     |                    |\n| `table_constraints`  | `list ` |                    |\n\n`COLUMN_SCHEMA` is a Struct with fields:\n\n| Field Name                 | Field Type  | Null Contstraint | Comments |\n|----------------------------|-------------|------------------|----------|\n| `column_name`              | `utf8`      | not null         |          |\n| `ordinal_position`         | `int32`     |                  | (1)      |\n| `remarks`                  | `utf8`      |                  | (2)      |\n| `xdbc_data_type`           | `int16`     |                  | (3)      |\n| `xdbc_type_name`           | `utf8`      |                  | (3)      |\n| `xdbc_column_size`         | `int32`     |                  | (3)      |\n| `xdbc_decimal_digits`      | `int16`     |                  | (3)      |\n| `xdbc_num_prec_radix`      | `int16`     |                  | (3)      |\n| `xdbc_nullable`            | `int16`     |                  | (3)      |\n| `xdbc_column_def`          | `utf8`      |                  | (3)      |\n| `xdbc_sql_data_type`       | `int16`     |                  | (3)      |\n| `xdbc_datetime_sub`        | `int16`     |                  | (3)      |\n| `xdbc_char_octet_length`   | `int32`     |                  | (3)      |\n| `xdbc_is_nullable`         | `utf8`      |                  | (3)      |\n| `xdbc_scope_catalog`       | `utf8`      |                  | (3)      |\n| `xdbc_scope_schema`        | `utf8`      |                  | (3)      |\n| `xdbc_scope_table`         | `utf8`      |                  | (3)      |\n| `xdbc_is_autoincrement`    | `bool`      |                  | (3)      |\n| `xdbc_is_generatedcolumn`  | `bool`      |                  | (3)      |\n\n1. The column's ordinal position in the table (starting from 1).\n2. Database-specific description of the column.\n3. Optional value. Should be null if not supported by the driver.\n   `xdbc_` values are meant to provide JDBC/ODBC-compatible metadata\n   in an agnostic manner.\n\n`CONSTRAINT_SCHEMA` is a Struct with fields:\n\n| Field Name                | Field Type           | Null Contstraint | Comments |\n|---------------------------|----------------------|------------------|----------|\n| `constraint_name`         | `utf8`               |                  |          |\n| `constraint_type`         | `utf8`               | not null         | (1)      |\n| `constraint_column_names` | `list `         | not null         | (2)      |\n| `constraint_column_usage` | `list ` |                  | (3)      |\n\n1. One of 'CHECK', 'FOREIGN KEY', 'PRIMARY KEY', or 'UNIQUE'.\n2. The columns on the current table that are constrained, in order.\n3. For FOREIGN KEY only, the referenced table and columns.\n\n`USAGE_SCHEMA` is a Struct with fields:\n\n| Field Name               | Field Type    | Null Contstraint |\n|--------------------------|---------------|------------------|\n| `fk_catalog`             | `utf8`        |                  |\n| `fk_db_schema`           | `utf8`        |                  |\n| `fk_table`               | `utf8`        | not null         |\n| `fk_column_name`         | `utf8`        | not null         |","title":"Adbc.Connection.get_objects/3","ref":"Adbc.Connection.html#get_objects/3"},{"type":"function","doc":"Get a string type option of the connection.","title":"Adbc.Connection.get_string_option/2","ref":"Adbc.Connection.html#get_string_option/2"},{"type":"function","doc":"Get a list of table types in the database.\n\nThe result is an Arrow dataset with the following schema:\n\n| Field Name     | Field Type    | Null Contstraint |\n|----------------|---------------|------------------|\n| `table_type`   | `utf8`        | not null         |","title":"Adbc.Connection.get_table_types/1","ref":"Adbc.Connection.html#get_table_types/1"},{"type":"function","doc":"Prepares the given `query`.","title":"Adbc.Connection.prepare/2","ref":"Adbc.Connection.html#prepare/2"},{"type":"function","doc":"Runs the given `query` with `params` and `statement_options`.","title":"Adbc.Connection.query/4","ref":"Adbc.Connection.html#query/4"},{"type":"function","doc":"Same as `query/4` but raises an exception on error.","title":"Adbc.Connection.query!/4","ref":"Adbc.Connection.html#query!/4"},{"type":"function","doc":"Runs the given `query` with `params` and\npass the ArrowStream pointer to the given function.\n\nThe pointer will point to a valid ArrowStream through\nthe duration of the function. The function may call\nnative code that consumes the ArrowStream accordingly.","title":"Adbc.Connection.query_pointer/5","ref":"Adbc.Connection.html#query_pointer/5"},{"type":"function","doc":"Set option for the connection.\n\n- If `value` is an atom or a string, then corresponding string option will be set.\n- If `value` is a `{:binary, binary()}`-tuple, then corresponding binary option will be set.\n- If `value` is an integer, then corresponding integer option will be set.\n- If `value` is a float, then corresponding float option will be set.","title":"Adbc.Connection.set_option/3","ref":"Adbc.Connection.html#set_option/3"},{"type":"function","doc":"Starts a connection process.","title":"Adbc.Connection.start_link/1","ref":"Adbc.Connection.html#start_link/1"},{"type":"function","doc":"* `:database` (required) - the database process to connect to\n\n  * `:process_options` - the options to be given to the underlying\n    process. See `GenServer.start_link/3` for all options","title":"Options - Adbc.Connection.start_link/1","ref":"Adbc.Connection.html#start_link/1-options"},{"type":"function","doc":"Adbc.Connection.start_link(\n      database: MyApp.DB,\n      process_options: [name: MyApp.Conn]\n    )\n\nIn your supervision tree it would be started like this:\n\n    children = [\n      {Adbc.Connection,\n       database: MyApp.DB,\n       process_options: [name: MyApp.Conn]}\n    ]","title":"Examples - Adbc.Connection.start_link/1","ref":"Adbc.Connection.html#start_link/1-examples"},{"type":"type","doc":"","title":"Adbc.Connection.result_set/0","ref":"Adbc.Connection.html#t:result_set/0"},{"type":"type","doc":"","title":"Adbc.Connection.t/0","ref":"Adbc.Connection.html#t:t/0"},{"type":"module","doc":"Documentation for `Adbc.Database`.\n\nDatabases are modelled as processes. They required\na driver to be started.","title":"Adbc.Database","ref":"Adbc.Database.html"},{"type":"function","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","title":"Adbc.Database.child_spec/1","ref":"Adbc.Database.html#child_spec/1"},{"type":"function","doc":"Get a binary (bytes) type option of the database.","title":"Adbc.Database.get_binary_option/2","ref":"Adbc.Database.html#get_binary_option/2"},{"type":"function","doc":"Get a float type option of the database.","title":"Adbc.Database.get_float_option/2","ref":"Adbc.Database.html#get_float_option/2"},{"type":"function","doc":"Get an integer type option of the database.","title":"Adbc.Database.get_integer_option/2","ref":"Adbc.Database.html#get_integer_option/2"},{"type":"function","doc":"Get a string type option of the database.","title":"Adbc.Database.get_string_option/2","ref":"Adbc.Database.html#get_string_option/2"},{"type":"function","doc":"Set option for the database.\n\n- If `value` is an atom or a string, then corresponding string option will be set.\n- If `value` is a `{:binary, binary()}`-tuple, then corresponding binary option will be set.\n- If `value` is an integer, then corresponding integer option will be set.\n- If `value` is a float, then corresponding float option will be set.","title":"Adbc.Database.set_option/3","ref":"Adbc.Database.html#set_option/3"},{"type":"function","doc":"Starts a database process.","title":"Adbc.Database.start_link/1","ref":"Adbc.Database.html#start_link/1"},{"type":"function","doc":"* `:driver` (required) - the driver to use for this database.\n    It must be an atom (see `Adbc` module documentation for all\n    built-in drivers) or a string representing the path to a driver\n\n  * `:process_options` - the options to be given to the underlying\n    process. See `GenServer.start_link/3` for all options\n\nAll other options are given as database options to the underlying driver.","title":"Options - Adbc.Database.start_link/1","ref":"Adbc.Database.html#start_link/1-options"},{"type":"function","doc":"Adbc.Database.start_link(\n      driver: :sqlite,\n      process_options: [name: MyApp.DB]\n    )\n\nIn your supervision tree it would be started like this:\n\n    children = [\n      {Adbc.Database,\n       driver: :sqlite,\n       process_options: [name: MyApp.DB]},\n    ]","title":"Examples - Adbc.Database.start_link/1","ref":"Adbc.Database.html#start_link/1-examples"},{"type":"module","doc":"A struct returned as result from queries.\n\nIt has two fields:\n\n  * `:data` - a list of `Adbc.Column`\n\n  * `:num_rows` - the number of rows returned, if returned\n    by the database","title":"Adbc.Result","ref":"Adbc.Result.html"},{"type":"function","doc":"Returns a map of columns as a result.","title":"Adbc.Result.to_map/1","ref":"Adbc.Result.html#to_map/1"},{"type":"type","doc":"","title":"Adbc.Result.t/0","ref":"Adbc.Result.html#t:t/0"},{"type":"exception","doc":"","title":"Adbc.Error","ref":"Adbc.Error.html"},{"type":"type","doc":"","title":"Adbc.Error.t/0","ref":"Adbc.Error.html#t:t/0"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}